//=========================================================
//  MusE
//  Linux Music Editor
//
//  type_defs.h
//  Copyright (C) 2012 Tim E. Real (terminator356 on users dot sourceforge dot net)
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; version 2 of
//  the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//
//=========================================================

#ifndef __TYPE_DEFS_H__
#define __TYPE_DEFS_H__

#include "stdint.h"

namespace MusECore {

typedef int64_t SongChangedFlags_t;
typedef int64_t EventID_t;
#define MUSE_INVALID_EVENT_ID   -1

}   // namespace MusECore

#endif
